@@ -2,7 +2,7 @@ import json
 import base64
 import zlib
 from enum import Enum
-from .iotcontrol import DeviceView, Menu, ButtonGroup, Button, TextBox, Graph, Dial, ColorPicker, TimeGraph, Selector, Slider, Direction, EventLog, Knob
+from .iotcontrol import Label, DeviceView, Menu, ButtonGroup, Button, TextBox, Graph, Dial, ColorPicker, TimeGraph, Selector, Slider, Direction, EventLog, Knob
 
 
 class ControlTitleJSON(Enum):
@@ -46,11 +46,7 @@ def decode_cfg64(cfg: str) -> dict:
     """
 
     ztmp_b = base64.b64decode(cfg)
-    try:
-        tmp_b = zlib.decompress(ztmp_b)
-    except zlib.error:
-        pass
-        # tmp_b = zlib.decompress(ztmp_b, wbits=-8)  # Deal with missing header
+    tmp_b = zlib.decompress(ztmp_b, wbits=-9)  # Deal with missing header
     try:
         cfg_dict = json.loads(tmp_b)
     except json.JSONDecodeError:
@@ -68,8 +64,10 @@ def encode_cfg64(cfg: dict) -> str:
         str: the cfg encoded as C64 format
     """
     cfg_json = json.dumps(cfg)
-    tmp_z = zlib.compress(cfg_json.encode('ascii'), 1)
-    return base64.b64encode(tmp_z)
+    compress = zlib.compressobj(6, zlib.DEFLATED, -9, zlib.DEF_MEM_LEVEL, zlib.Z_DEFAULT_STRATEGY)
+    tmp_z = compress.compress(cfg_json.encode())
+    tmp_z += compress.flush()
+    return base64.b64encode(tmp_z).decode()
 
 
 def load_controls_from_config(device, cfg_dict) -> dict:
@@ -88,65 +86,69 @@ def load_controls_from_config(device, cfg_dict) -> dict:
         Dictionary of the control objects
     """
     controls_dict = {}
-    for device_view in cfg_dict["deviceViews"]:
+    for device_view in cfg_dict["DVVW"]:
         controls_dict[device_view["controlID"]] = DeviceView.from_cfg_dict(device_view)
         device.add_control(controls_dict[device_view["controlID"]])
-    for menu in cfg_dict["menus"]:
+    for menu in cfg_dict["MENU"]:
         controls_dict[menu["controlID"]] = Menu.from_cfg_dict(menu)
         controls_dict[menu["parentID"]].add_control(controls_dict[menu["controlID"]])
         device.add_control(controls_dict[menu["controlID"]])
-    for button_g in cfg_dict["buttonGroups"]:
+    for button_g in cfg_dict["BTGP"]:
         controls_dict[button_g["controlID"]] = ButtonGroup.from_cfg_dict(button_g)
         controls_dict[button_g["parentID"]].add_control(controls_dict[button_g["controlID"]])
         device.add_control(controls_dict[button_g["controlID"]])
-    for button in cfg_dict["buttons"]:
+    for button in cfg_dict["BTTN"]:
         controls_dict[button["controlID"]] = Button.from_cfg_dict(button)
         controls_dict[button["parentID"]].add_control(controls_dict[button["controlID"]])
         device.add_control(controls_dict[button["controlID"]])
-    for text_box in cfg_dict["textBoxes"]:
+    for text_box in cfg_dict["TEXT"]:
         controls_dict[text_box["controlID"]] = TextBox.from_cfg_dict(text_box)
         controls_dict[text_box["parentID"]].add_control(controls_dict[text_box["controlID"]])
         device.add_control(controls_dict[text_box["controlID"]])
-    for graph in cfg_dict["graphs"]:
+    for graph in cfg_dict["GRPH"]:
         controls_dict[graph["controlID"]] = Graph.from_cfg_dict(graph)
         controls_dict[graph["parentID"]].add_control(controls_dict[graph["controlID"]])
         device.add_control(controls_dict[graph["controlID"]])
-    for dial in cfg_dict["dials"]:
+    for dial in cfg_dict["DIAL"]:
         controls_dict[dial["controlID"]] = Dial.from_cfg_dict(dial)
         controls_dict[dial["parentID"]].add_control(controls_dict[dial["controlID"]])
         device.add_control(controls_dict[dial["controlID"]])
-    for color_p in cfg_dict["colours"]:
+    for color_p in cfg_dict["CLR"]:
         controls_dict[color_p["controlID"]] = ColorPicker.from_cfg_dict(color_p)
         controls_dict[color_p["parentID"]].add_control(controls_dict[color_p["controlID"]])
         device.add_control(controls_dict[color_p["controlID"]])
-    for knob in cfg_dict["knobs"]:
+    for knob in cfg_dict["KNOB"]:
         controls_dict[knob["controlID"]] = Knob.from_cfg_dict(knob)
         controls_dict[knob["parentID"]].add_control(controls_dict[knob["controlID"]])
         device.add_control(controls_dict[knob["controlID"]])
-    for time_graph in cfg_dict["timeGraphs"]:
+    for time_graph in cfg_dict["TGRPH"]:
         controls_dict[time_graph["controlID"]] = TimeGraph.from_cfg_dict(time_graph)
         controls_dict[time_graph["parentID"]].add_control(controls_dict[time_graph["controlID"]])
         device.add_control(controls_dict[time_graph["controlID"]])
-    for selector in cfg_dict["selectors"]:
+    for selector in cfg_dict["SLCTR"]:
         controls_dict[selector["controlID"]] = Selector.from_cfg_dict(selector)
         controls_dict[selector["parentID"]].add_control(controls_dict[selector["controlID"]])
         device.add_control(controls_dict[selector["controlID"]])
-    for slider in cfg_dict["sliders"]:
+    for slider in cfg_dict["SLDR"]:
         controls_dict[slider["controlID"]] = Slider.from_cfg_dict(slider)
         controls_dict[slider["parentID"]].add_control(controls_dict[slider["controlID"]])
         device.add_control(controls_dict[slider["controlID"]])
-    for direction in cfg_dict["directions"]:
+    for direction in cfg_dict["DIR"]:
         controls_dict[direction["controlID"]] = Direction.from_cfg_dict(direction)
         controls_dict[direction["parentID"]].add_control(controls_dict[direction["controlID"]])
         device.add_control(controls_dict[direction["controlID"]])
-    for even_log in cfg_dict["eventLogs"]:
-        controls_dict[even_log["controlID"]] = EventLog.from_cfg_dict(even_log)
-        controls_dict[even_log["parentID"]].add_control(controls_dict[even_log["controlID"]])
-        device.add_control(controls_dict[even_log["controlID"]])
+    for event_log in cfg_dict["LOG"]:
+        controls_dict[event_log["controlID"]] = EventLog.from_cfg_dict(event_log)
+        controls_dict[event_log["parentID"]].add_control(controls_dict[event_log["controlID"]])
+        device.add_control(controls_dict[event_log["controlID"]])
+    for label in cfg_dict["LBL"]:
+        controls_dict[label["controlID"]] = Label.from_cfg_dict(label)
+        controls_dict[label["parentID"]].add_control(controls_dict[label["controlID"]])
+        device.add_control(controls_dict[label["controlID"]])
+
     #  for audio_visual in cfg_dict["audioVisuals"]:
         # TODO
     #    pass
     #
     return controls_dict
 
-
